# Why Open?

The practice of “open science\footnote{The \textit{Encyclopædia Britannica} defines science as “any system of knowledge that is concerned with the physical world and its phenomena and that entails unbiased observations and systematic experimentation”. Source: \url{https://global.britannica.com/topic/science}}”, or more broadly “open research”, has come a long way since it emerged as a movement, in the 2000s: it is helpful to signpost its early days with the Budapest Open Access Initiative\footnote{\url{http://www.budapestopenaccessinitiative.org/}}, which was published on 14 February 2002.

Open research was initially driven by the principle of providing free-to-read access to publications that are the result of publicly funded research (“open access”), which has been shown to have academic, economic and societal impacts [**ADD CITATION**]\footnote{Incidentally, this paper was authored in the public, encouraging any interested parties to make a contribution to the draft: \url{https://www.overleaf.com/3730902jgbrvw}.}.
The term has broadened its scope and now addresses open data, free/libre and open-source software (sometimes abbreviated as FLOSS), open research code and open laboratory notebooks as well as providing scholarly content under more permissive licences (such as Creative Commons\footnote{\url{https://creativecommons.org/}}).
Discussions concerning open practices in research have grown in recent months as a result of the so-called “reproducibility crisis”[**ADD CITATION**], prompting a deeper reflection within academia concerning the transparency and rigour of research.
(For a comprehensive take on some of the ails of legacy research practices as well as proposed solutions, see Ihle *et al.*[**ADD CITATION**])
In their exhaustive overview of modern publishing paradigms, Heller *et al.* [**ADD CITATION**] touch upon another aspect of open research, namely open authoring: “Technically the whole textual creation process including all typing and editing could be open. Furthermore, all commentary and discussion can be open. Certain consequences are related to such openness.”
This aspect has, however, received less attention from the scholarly community, despite a proliferation of tools to aid such authorship\footnote{Collaborative editing platforms such as Authorea (\url{https://www.authorea.com/}) and Overleaf (\url{https://www.overleaf.com/}) have attempted to make open authoring the norm. Authors of proceedings of the SciPy conference have been required to submit their documents for public review using the platform GitHub (see \url{https://github.com/scipy-conference/scipy_proceedings}), while journals such as PeerJ have built their own tools -- \url{https://github.com/PeerJ/paper-now} -- for open authoring of research papers (see a “live” paper at \url{https://katrinleinweber.github.io/paper-now/} and its peer-reviewed version at \url{https://doi.org/10.7717/peerj.858}). Other examples of openly authored papers I have come across include \url{https://github.com/karthik/smb_git} and \url{https://github.com/ContentMine/cm-ucl/tree/master/eswc}.}.

Below, I wish to present my arguments in support of open authoring, including doing so with one’s doctoral thesis, as it is especially important to train the next generation of researchers in openness.

## Schools of thought

Fecher & Friesike have proposed that the discourse surrounding open research falls under five distinct schools of thought[**ADD CITATION**].
I submit that open authoring satisfies each of these schools of thought, as follows:

\begin{enumerate}
    \item \textbf{Democratic}: If the aim of openness is to make knowledge freely available to everyone, then the experience associated with this knowledge generation should also be made freely available by authoring the research outputs openly.
    \item \textbf{Pragmatic}: By openly authoring a doctoral thesis, the researcher opens up the possibility of errors, both minor (typos) and major (missing citations or incorrect/outdated references), being spotted by any member of society with access to the text, thereby enhancing the quality of the research output.
    \item \textbf{Infrastructure}: In exploring available tools for open research and developing workflows that suit oneself, the researcher is not only equipping themself to work openly, but might potentially establish a toolkit that can be used by other researchers.
    \item \textbf{Public}: One of the challenges of open research is to make the work accessible and understandable to non-experts, and comments received from such non-experts during the process of authoring can force the researcher to revisit their work with a fresh perspective, which will improve the accessibility of the final product.
    \item \textbf{Measurement}: Openness
\end{enumerate}

# How to “do” Open?

- Publish every word and every change publicly from the start
- Include scripts and data where possible, so plots can be rebuilt by third parties at an early stage, if needed

## Openly authored theses: examples

- https://en.wikipedia.org/wiki/Wikipedia:WikiProject_Open/Open_theses
- https://github.com/chartgerink/dissertation
- http://rik.smith-unna.com/phd/thesis.html
- https://github.com/Tontonis/Thesis_the_second
- http://offene-doktorarbeit.de/

# Concerns with openness

- University stance…

## Demonstrating authorship

- Git commits signed with PGP key
- No need to rely only on author’s word

## The elephant in the room: “third-party advice”

- Issue tracker
- Commenting system

## Concerns for the researcher

- Learn new tools, invest time

# Open thesis: workflow

- I will use Authorea/Bookdown (probably the latter) to draft the text openly
- Make my work available under a CC licence

## My open-authoring practices so far

- Conference talks
- Conference proceedings
- Posters
- Book chapters

## Additional “open” elements to the research

- Insistence on using open source
- Sharing code publicly (notebooks)
- Pledge to make data open
- Pledge for all papers to be published under OA licences

# Conclusions

## Reflections

- The question should not be "why open" but "why closed": i.e., research should be conducted as openly as possible unless there are very valid reasons for making things closed. Ethics committees should approve a closed approach where needed.
- Research is not a lone-wolf endeavour: increasingly we collaborate not just across geographic boundaries but across discipline ones.
- Writing a doctoral thesis is a taxing and challenging endeavour: it would help immeasurably to know the struggles other candidates have faced as well as their successes in overcoming the challenges presented.
- I am aware that no-one will look at the thesis-in-production, but it's the principle that counts.
